Index: /trunk/Ohana/src/gastro2/src/greference2.c
===================================================================
--- /trunk/Ohana/src/gastro2/src/greference2.c	(revision 5132)
+++ /trunk/Ohana/src/gastro2/src/greference2.c	(revision 5133)
@@ -10,5 +10,5 @@
 
   Ref[0].N = 0;
-  /* get stars from the USNO catalog for the given region */
+  /* get stars from the USNO A catalog for the given region */
   if (!strcmp (REFCAT, "USNO")) {
     getusno (&catstats, Ref);
@@ -21,10 +21,12 @@
   }
   
-  /* get stars from the HST GSC catalog for the given region */
+  /* get stars from 2MASS for the given region -- add PHOTCODE check? */
   if (!strcmp (REFCAT, "2MASS")) {
-    get2mass (&catstats, Ref);
+    strcpy (CATDIR, TWO_MASS_DIR);
+    getptolemy (&catstats, Ref);
+    /* get2mass (&catstats, Ref); */
   }
   
   /* get stars from the HST GSC catalog for the given region */
   if (!strcmp (REFCAT, "PTOLEMY")) {
     getptolemy (&catstats, Ref);
@@ -21,10 +21,12 @@
   }
   
-  /* get stars from the HST GSC catalog for the given region */
+  /* get stars from the DVO CATDIR for the given region */
   if (!strcmp (REFCAT, "PTOLEMY")) {
     getptolemy (&catstats, Ref);
Index: /trunk/Ohana/src/mosastro/src/greference.c
===================================================================
--- /trunk/Ohana/src/mosastro/src/greference.c	(revision 5132)
+++ /trunk/Ohana/src/mosastro/src/greference.c	(revision 5133)
@@ -23,5 +23,5 @@
   }
 
-  /* get stars from the USNO catalog for the given region */
+  /* get stars from the USNO A catalog for the given region */
   if (!strcmp (REFCAT, "USNO")) {
     stars = getusno (&catstats, &Nstars);
@@ -33,10 +33,12 @@
   }
   
-  /* get stars from the HST GSC catalog for the given region */
+  /* get stars from 2MASS for the given region -- add PHOTCODE check? */
   if (!strcmp (REFCAT, "2MASS")) {
-    stars = get2mass (&catstats, &Nstars);
+    strcpy (CATDIR, TWO_MASS_DIR);
+    stars = getptolemy (&catstats, &Nstars);
+    /* stars = get2mass (&catstats, &Nstars); */
   }
   
   /* get stars from the HST GSC catalog for the given region */
   if (!strcmp (REFCAT, "PTOLEMY")) {
     stars = getptolemy (&catstats, &Nstars);
@@ -33,10 +33,12 @@
   }
   
-  /* get stars from the HST GSC catalog for the given region */
+  /* get stars from the DVO CATDIR for the given region */
   if (!strcmp (REFCAT, "PTOLEMY")) {
     stars = getptolemy (&catstats, &Nstars);
